@@ -1,5 +1,5 @@
 ## ---- eval = FALSE------------------------------------------------------------
-#  devtools::install_github("ipeaGIT/gtfs2gps")
+#  install.packages("gtfs2gps")
 
 ## -----------------------------------------------------------------------------
 library("data.table")
@@ -25,24 +25,32 @@ box()
 write_gtfs(sao_small, "sao_small.zip")
 
 ## ---- message = FALSE---------------------------------------------------------
-  sao_gps <- gtfs2gps("sao_small.zip", progress = FALSE, parallel = FALSE, spatial_resolution = 15)
+  sao_gps <- gtfs2gps("sao_small.zip", progress = FALSE, parallel = FALSE, spatial_resolution = 50)
   head(sao_gps)
 
 ## ---- message = FALSE---------------------------------------------------------
-  shapes_sf <- gps_as_sf(sao_gps)
   sao_gps60 <- sao_gps[1:100, ]
-  sao_gps60_sf <- gps_as_sf(sao_gps60)
-  plot(sf::st_geometry(sao_gps60_sf), pch = 20)
-  plot(sf::st_geometry(sao_small_shapes_sf), col = "blue", add = TRUE)
+  
+  # points
+  sao_gps60_sfpoints <- gps_as_sfpoints(sao_gps60)
+  
+  # linestring
+  sao_gps60_sflinestring <- gps_as_sflinestring(sao_gps60)
+
+  # plot
+  plot(sf::st_geometry(sao_gps60_sfpoints), pch = 20)
+  plot(sf::st_geometry(sao_gps60_sflinestring), col = "blue", add = TRUE)
   box()
 
 ## ---- message = FALSE---------------------------------------------------------
 poa <- system.file("extdata/poa.zip", package ="gtfs2gps")
-poa_gps <- gtfs2gps(poa, progress = FALSE, parallel = FALSE, spatial_resolution = 15)
-poa_gps_sf <- gps_as_sf(poa_gps)
-poa_sf <- read_gtfs(poa) %>% gtfs_shapes_as_sf()
-plot(sf::st_geometry(poa_gps_sf[1:200,]))
-plot(sf::st_geometry(poa_sf), col = "blue", add = TRUE)
+
+poa_gps <- gtfs2gps(poa, progress = FALSE, parallel = FALSE, spatial_resolution = 50)
+
+poa_gps_sflinestrig <- gps_as_sfpoints(poa_gps)
+
+plot(sf::st_geometry(poa_gps_sflinestrig[1:200,]))
+
 box()
 
 ## ----speed, echo = FALSE, message = FALSE-------------------------------------
