@@ -5,7 +5,8 @@ test_that("append_height", {
   
   gtfs <- read_gtfs(fortaleza) %>%
     filter_week_days() %>%
-    filter_single_trip()
+    filter_single_trip() %>% 
+    remove_invalid()
   
   fortaleza_gps <- gtfs2gps(gtfs, progress = FALSE) %>% append_height(srtmfile)
 
