@@ -14,5 +14,5 @@ test_that("gps_as_sflinestring", {
   expect_true(is(for_gps_sf_lines, "sf"))
 
   expect_equal(dim(for_gps_sf_lines)[1], 39)
-  expect_equal(for_gps_sf_lines$stop_id[1], 2649)
+  expect_equal(for_gps_sf_lines$stop_id[1], "2649")
 })
