@@ -30,9 +30,9 @@ test_that("read_gtfs", {
 
     unzip("poa.zip")
 
-    files <- c("agency.txt", "routes.txt", "stops.txt", "stop_times.txt", "shapes.txt", "trips.txt", "calendar.txt")
+    files <- c("routes.txt", "stops.txt", "stop_times.txt", "shapes.txt", "trips.txt", "calendar.txt", "agency.txt")
 
-    for(i in 1:length(files)){
+    for(i in 1:(length(files)-2)){
       if(file.exists("myfile.zip")) file.remove("myfile.zip")
       zip("myfile.zip", files[-i], flags = "-q")
       expect_error(read_gtfs("myfile.zip"), paste("File", files[i], "is missing"))
